@@ -33,20 +33,31 @@
 #' @param palette function. A color palette function. Default is \code{height.colors} provided by the package lidR.
 #' @param trim numeric.
 #' @keywords internal
-set.colors = function(x, palette, trim = Inf)
+set.colors = function(x, palette, trim = Inf, value_index = FALSE)
 {
   if (all(is.na(x)))
-    return(rep("lightgrey", length(x)))
+    return()
+
+  # Classification case
+  if (value_index)
+  {
+    x[x >= length(palette)] <- length(palette) - 1
+    return(palette[x + 1])
+  }
 
   ncolors <- length(palette)
-  if(!is.infinite(trim)) x[x > trim] <- trim
+  if (!is.infinite(trim)) x[x > trim] <- trim
   minx <- min(x, na.rm = T)
   maxx <- max(x, na.rm = T)
 
-  if (maxx-minx == 0)
-    colors <- palette[1]
-  else
-  {
+  if (maxx - minx == 0) {
+    if (!anyNA(x)) {
+      colors <- palette[1]
+    } else {
+      colors <- rep(NA_character_, length(x))
+      colors[!is.na(x)] <- palette[1]
+    }
+  } else {
     idx <- findInterval(x, seq(minx, maxx, length.out = ncolors))
     colors <- palette[idx]
   }
@@ -105,4 +116,27 @@ pastel.colors = function(n)
   l = stats::runif(n, 40, 90);
 
   return(grDevices::hcl(h,c,l))
-}
\ No newline at end of file
+}
+
+lasclass.colors = function()
+{
+  return(c("lightgrey",   # 0 never classifiied
+           "lightgray",   # 1 unclassified
+           "blue",        # 2 ground
+           "limegreen",   # 3 low vegetation
+           "forestgreen", # 4 medium vegetation
+           "darkgreen",   # 5 high vegetation
+           "red",         # 6 building
+           "yellow",      # 7 low point (noise)
+           "yellow",      # 8 reserved
+           "#6495ED",     # 9 water
+           "yellow",      # 10 rail
+           "gray20",      # 11 Road surface
+           "yellow",      # 12 reserved
+           "pink",        # 13 wire
+           "pink",        # 14 wire
+           "purple",      # 15 transmission tower
+           "pink",        # 16 Wire connector
+           "orange",      # 17 bridge deck
+           "yellow"))     # +
+}
